/**
 * <p>Amazon EventBridge helps you to respond to state changes in your Amazon Web Services
 *       resources. When your resources change state, they automatically send events to an event
 *       stream. You can create rules that match selected events in the stream and route them to
 *       targets to take action. You can also use rules to take action on a predetermined schedule. For
 *       example, you can configure rules to:</p>
 *          <ul>
 *             <li>
 *                <p>Automatically invoke an Lambda function to update DNS entries when an
 *           event notifies you that Amazon EC2 instance enters the running state.</p>
 *             </li>
 *             <li>
 *                <p>Direct specific API records from CloudTrail to an Amazon Kinesis
 *           data stream for detailed analysis of potential security or availability risks.</p>
 *             </li>
 *             <li>
 *                <p>Periodically invoke a built-in target to create a snapshot of an Amazon EBS
 *           volume.</p>
 *             </li>
 *          </ul>
 *          <p>For more information about the features of Amazon EventBridge, see the <a href="https://docs.aws.amazon.com/eventbridge/latest/userguide">Amazon EventBridge User
 *         Guide</a>.</p>
 *
 * @packageDocumentation
 */
export * from "./EventBridgeClient";
export * from "./EventBridge";
export { ClientInputEndpointParameters } from "./endpoint/EndpointParameters";
export type { RuntimeExtension } from "./runtimeExtensions";
export type { EventBridgeExtensionConfiguration } from "./extensionConfiguration";
export * from "./commands";
export * from "./models";
export { EventBridgeServiceException } from "./models/EventBridgeServiceException";
